@@ -1,12 +1,12 @@
 ;;;; -*- scheme -*-
 ;;;; This file is part of GNU Radius.
-;;;; Copyright (C) 2004 Free Software Foundation, Inc.
+;;;; Copyright (C) 2004, 2007 Free Software Foundation, Inc.
 ;;;;
 ;;;; Written by Sergey Poznyakoff
 ;;;;
 ;;;; GNU Radius is free software; you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
-;;;; the Free Software Foundation; either version 2 of the License, or
+;;;; the Free Software Foundation; either version 3 of the License, or
 ;;;; (at your option) any later version.
 ;;;;
 ;;;; GNU Radius is distributed in the hope that it will be useful,
@@ -23,9 +23,9 @@
 (define-module (gnuradius)
   :use-module (ice-9 format))
 
-(let ((lib-path "/home/gray/alpha/lib/"))
+(let ((lib-path "/usr/local/lib/"))
   (load-extension (string-append
-		   lib-path "libguile-gnuradius-v-1.4") "radscm_init"))
+		   lib-path "libguile-gnuradius-v-1.5") "radscm_init"))
 
 ;; Exports go here
 (export %raddb-path
